"""Native LLVM IR compilation passes for na {} blocks."""

from jaclang.compiler.passes.native.na_compile_pass import (
    NativeCompilePass,  # noqa: F401
)
from jaclang.compiler.passes.native.na_ir_gen_pass import NaIRGenPass  # noqa: F401
