# typing.pyi file definitions for special forms
class Final: ...
class LiteralString(str): ...

# Core Jaclang builtin types
class Node: ...
class Walker: ...
class Root(Node): ...

# JSX types for client-side rendering
class JsxElement:
    tag: object
    props: dict[str, object]
    children: list[object]
